@@ -1,11 +1,9 @@
 from netnir.helpers.scaffold.command import CommandScaffold
 from netnir.helpers.common.args import num_workers
 from netnir.helpers import output_writer
-from netnir.core.networking import Networking
+from netnir.plugins.netmiko import netmiko_send_commands
 from nornir.plugins.functions.text import print_result
 
-"""fetch remove device configs"""
-
 
 class FetchConfig(CommandScaffold):
     """
@@ -28,8 +26,7 @@ class FetchConfig(CommandScaffold):
         """
 
         self.nr = self._inventory()
-        networking = Networking(nr=self.nr, num_workers=self.args.workers)
-        results = networking.fetch(commands="show running")
+        results = self.nr.run(task=netmiko_send_commands, commands="show running")
         output_writer(nornir_results=results, output_file="running.conf")
 
         return print_result(results)
