@@ -1,16 +1,12 @@
 from netnir.helpers.scaffold.command import CommandScaffold
-from netnir.core.networking import Networking
+from netnir.plugins.netmiko import netmiko_send_commands, netmiko_send_config
 from netnir.helpers import output_writer
 from netnir.helpers.common.args import (
     output,
-    num_workers,
     commands,
     config,
 )
 from nornir.plugins.functions.text import print_result
-import sys
-
-"""ssh cli commands"""
 
 
 class Ssh(CommandScaffold):
@@ -25,7 +21,6 @@ class Ssh(CommandScaffold):
         """
         CommandScaffold.parser(parser)
         output(parser)
-        num_workers(parser)
         commands(parser)
         config(parser)
 
@@ -35,22 +30,23 @@ class Ssh(CommandScaffold):
         """
 
         self.nr = self._inventory()
-        networking = Networking(nr=self.nr, num_workers=self.args.workers,)
 
         if self.args.config:
-            results = networking.config(self.args.commands)
-        elif self.args.commands:
-            results = networking.fetch(self.args.commands)
+            results = self.nr.run(
+                task=netmiko_send_config,
+                commands=self.args.commands,
+                name="SSH CONFIG EXECUTION",
+            )
         else:
-            sys.exit()
+            results = self.nr.run(
+                task=netmiko_send_commands,
+                commands=self.args.commands,
+                name="SSH COMMAND EXECUTION",
+            )
 
-        if isinstance(results, str):
-            results = [results]
+        if self.args.output:
+            output_writer(nornir_results=results, output_file=self.args.output)
 
-        for task in results:
-            if self.args.output:
-                output_writer(nornir_results=task, output_file=self.args.output)
-
-            print_result(task)
+        print_result(results)
 
         return results
